## qary for individuals  - add column for data required


### Contact - related
- Who is \<person I met before\>? (requires contacts )
- Where did I meet \<person I met before \>?
- Add note: \<note content\> 
- Where have I seen an article like this recently about the psychology of bots?
- Who do I know in the nonprofit space in San Francisco? 
- What is <term>?

### Health ()
- What are the symptoms of celiac disease? 
- What is the good regiment to boost my testosterone levels?
- What sorts of things might trigger a seizure in my 13 year old son on a road trip to Vegas?
- How do I get over a heartbreak?
- What's the best way you can break up with someone?
- What are the questions you should ask you a fiancee? 
- What's a good conversation starter with <contact>?
- Can you suggest a video to watch to cheer me up? (Triggered suggestion)
- Content recommendation engine for stuff to read (Books, videos, songs)
 

### Hobbies / Cooking / Housework 
- What's a good sourdough recipe?
- What's a good fertilizer for a tomato?
- How to get a wine stain of a dress?

### Technical
- What's the best machine learning algorithm for stock forecasting?

- How much did we pay the vendor for the recent contract in ...?
- What's the average salary of a CEO of a nonprofit?
- How many coops split equity and salary equally? 
- What are some good templates for incorporation?
- What's required for 501(c)3 certification by IRS?
- What does "null" mean in "Graduation" in our <> database?


- What is form WC-4?
- When was the last accident on site <X>?
- What is the repair procedure on <valve>?
- How many times

### Advanced ideas 
- Insight engine - translation from conversational query to SQL 


## Challenges
- Named entity de-referencing - how to resolve ambiguity between personal contacts and cyclopedic knowledge?
- 